@@ -51,7 +51,7 @@ namespace xt
      *
      * @tparam EC The type of the container holding the elements.
      * @tparam SC The type of the containers holding the shape and the strides.
-     * @sa xarray,  move_reshape
+     * @sa xarray
      */
     template <class EC, class SC>
     class xarray_container : public xstrided_container<xarray_container<EC, SC>>,
@@ -70,13 +70,16 @@ namespace xt
         using pointer = typename base_type::pointer;
         using const_pointer = typename base_type::const_pointer;
         using shape_type = typename base_type::shape_type;
+        using inner_shape_type = typename base_type::inner_shape_type;
         using strides_type = typename base_type::strides_type;
+        using inner_strides_type = typename base_type::inner_strides_type;
 
         xarray_container();
         explicit xarray_container(const shape_type& shape, layout l = layout::row_major);
         explicit xarray_container(const shape_type& shape, const_reference value, layout l = layout::row_major);
         explicit xarray_container(const shape_type& shape, const strides_type& strides);
         explicit xarray_container(const shape_type& shape, const strides_type& strides, const_reference value);
+        explicit xarray_container(container_type&& data, inner_shape_type&& shape, inner_strides_type&& strides);
 
         xarray_container(const value_type& t);
         xarray_container(nested_initializer_list_t<value_type, 1> t);
@@ -101,17 +104,12 @@ namespace xt
 
     private:
 
-        xarray_container(EC&& data, const shape_type& shape, const strides_type& strides);
-
         container_type m_data;
 
         container_type& data_impl() noexcept;
         const container_type& data_impl() const noexcept;
 
         friend class xcontainer<xarray_container<EC, SC>>;
-
-        template <class EC2, class SC2>
-        friend xarray_container<EC2, SC2> move_reshape(xarray_container<EC2, SC2>&& data, const SC2& shape, const SC2& strides);
     };
 
     /******************************
@@ -152,7 +150,6 @@ namespace xt
      *
      * @tparam EC The container type to adapt.
      * @tparam SC The type of the containers holding the shape and the strides.
-     * @sa move_reshape
      */
     template <class EC, class SC>
     class xarray_adaptor : public xstrided_container<xarray_adaptor<EC, SC>>,
@@ -185,8 +182,6 @@ namespace xt
 
     private:
 
-        xarray_adaptor(EC&& data, const shape_type& shape, const strides_type& strides);
-
         container_type& m_data;
 
         container_type& data_impl() noexcept;
@@ -197,30 +192,8 @@ namespace xt
 
         friend class xcontainer<xarray_adaptor<EC, SC>>;
         friend class xadaptor_semantic<xarray_adaptor<EC, SC>>;
-
-        template <class EC2, class SC2>
-        friend xarray_adaptor<EC2, SC2> move_reshape(xarray_adaptor<EC2, SC2>&& data, const SC2& shape, const SC2& strides);
     };
 
-    /****************
-     * move_reshape *
-     ****************/
-
-    template <template <class, class> class C, class EC, class SC>
-    C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape);
-
-    template <template <class, class> class C, class EC, class SC>
-    C<EC, SC> move_reshape(C<EC, SC>&& rhs, const SC& shape);
-
-    template <template <class, class> class C, class EC, class SC>
-    C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape, const SC& strides);
-
-    template <class EC, class SC>
-    xarray_container<EC, SC> move_reshape(xarray_container<EC, SC>&& rhs, const SC& shape, const SC& strides);
-
-    template <class EC, class SC>
-    xarray_adaptor<EC, SC> move_reshape(xarray_adaptor<EC, SC>&& rhs, const SC& shape, const SC& strides);
-
     /***********************************
      * xarray_container implementation *
      ***********************************/
@@ -305,6 +278,19 @@ namespace xt
         base_type::reshape(xt::shape<shape_type>(t), layout::row_major);
         nested_copy(m_data.begin(), t);
     }
+
+    /**
+     * Allocates an xarray_container by moving specified data, shape and strides
+     *
+     * @param data the data for the xarray_container
+     * @param shape the shape of the xarray_container
+     * @param strides the strides of the xarray_container
+     */
+    template <class EC, class SC>
+    inline xarray_container<EC, SC>::xarray_container(container_type&& data, inner_shape_type&& shape, inner_strides_type&& strides)
+        : base_type(std::move(shape), std::move(strides)), m_data(std::move(data))
+    {
+    }
     //@}
 
     /**
@@ -399,13 +385,6 @@ namespace xt
     }
     //@}
 
-    template <class EC, class SC>
-    inline xarray_container<EC, SC>::xarray_container(EC&& data, const shape_type& shape, const strides_type& strides)
-        : base_type(), m_data(std::move(data))
-    {
-        base_type::reshape(shape, strides);
-    }
-
     template <class EC, class SC>
     inline auto xarray_container<EC, SC>::data_impl() noexcept -> container_type&
     {
@@ -496,13 +475,6 @@ namespace xt
     }
     //@}
 
-    template <class EC, class SC>
-    inline xarray_adaptor<EC, SC>::xarray_adaptor(EC&& data, const shape_type& shape, const strides_type& strides)
-        : base_type(), m_data(data)
-    {
-        base_type::reshape(shape, strides);
-    }
-
     template <class EC, class SC>
     inline auto xarray_adaptor<EC, SC>::data_impl() noexcept -> container_type&
     {
@@ -526,64 +498,6 @@ namespace xt
         m_data.resize(tmp.size());
         std::copy(tmp.data().cbegin(), tmp.data().cend(), m_data.begin());
     }
-
-    /*******************************
-     * move_reshape implementation *
-     *******************************/
-
-    template <template <class, class> class C, class EC, class SC>
-    inline C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape)
-    {
-        return move_reshape(std::move(rhs), shape);
-    }
-
-    template <template <class, class> class C, class EC, class SC>
-    inline C<EC, SC> move_reshape(C<EC, SC>&& rhs, const SC& shape)
-    {
-        SC strides(shape.size());
-        compute_strides(shape, layout::row_major, strides);
-        return move_reshape(std::move(rhs), shape, strides);
-    }
-
-    template <template <class, class> class C, class EC, class SC>
-    inline C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape, const SC& strides)
-    {
-        return move_reshape(std::move(rhs), shape, strides);
-    }
-
-    /**
-     * Moves the data of the specified multidimensional array into a new multidimensional array
-     * that is reshaped with the given shape and strides. The original array is invalidated.
-     * This method should not be used directly, it is provided for consitency with xtensor. The
-     * reshape method should be used instead.
-     *
-     * @param rhs the multidimensional array to reshape. May be passed as lvalue or rvalue reference.
-     * @param shape the new shape.
-     * @param strides the new strides. If omitted, the strides are computed so the new array
-     *                has a row major layout.
-     */
-    template <class EC, class SC>
-    inline xarray_container<EC, SC> move_reshape(xarray_container<EC, SC>&& rhs, const SC& shape, const SC& strides)
-    {
-        return xarray_container<EC, SC>(std::move(rhs.m_data), shape, strides);
-    }
-
-    /**
-     * Moves the data of the specified multidimensional array adaptor into a new multidimensional array
-     * and reshapes it with the given shape and strides. The original array adapter is invalidated.
-     * This method should not be used directly, it is provided for consitency with xtensor. The reshape
-     * method should be used instead.
-     *
-     * @param rhs the mutldimensional arrat adaptor to reshape. May be passed as lvalue or rvalue reference.
-     * @param shape the new shape.
-     * @param strides the new strides. If omitted, the strides are computed so the new multidimensional array
-     *                adaptor has a row major layout.
-     */
-    template <class EC, class SC>
-    inline xarray_adaptor<EC, SC> move_reshape(xarray_adaptor<EC, SC>&& rhs, const SC& shape, const SC& strides)
-    {
-        return xarray_adaptor<EC, SC>(std::move(rhs.m_data), shape, strides);
-    }
 }
 
 #endif
