@@ -9,17 +9,18 @@
 #ifndef XVIEW_HPP
 #define XVIEW_HPP
 
-#include <cstddef>
-#include <utility>
-#include <type_traits>
-#include <tuple>
-#include <array>
 #include <algorithm>
+#include <array>
+#include <cstddef>
+#include <tuple>
+#include <type_traits>
+#include <utility>
 
-#include "xtensor_forward.hpp"
 #include "xbroadcast.hpp"
+#include "xcontainer.hpp"
 #include "xiterable.hpp"
 #include "xsemantic.hpp"
+#include "xtensor_forward.hpp"
 #include "xview_utils.hpp"
 
 namespace xt
@@ -103,8 +104,8 @@ namespace xt
         using iterator = typename iterable_base::iterator;
         using const_iterator = typename iterable_base::const_iterator;
 
-        template <class... SL>
-        xview(CT e, SL&&... slices) noexcept;
+        template <class CTA, class... SL>
+        xview(CTA&& e, SL&&... slices) noexcept;
 
         template <class E>
         self_type& operator=(const xexpression<E>& e);
@@ -148,6 +149,26 @@ namespace xt
         template <class ST>
         const_stepper stepper_end(const ST& shape) const;
 
+        template <class T = xexpression_type>
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::container_type&>
+        data() const;
+
+        template <class T = xexpression_type>
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::strides_type>
+        strides() const;
+
+        template <class T = xexpression_type>
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const value_type*>
+        raw_data() const;
+
+        template <class T = xexpression_type>
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, value_type*>
+        raw_data();
+
+        template <class T = xexpression_type>
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::size_type>
+        raw_data_offset() const;
+
     private:
 
         // VS 2015 workaround (yes, really)
@@ -170,16 +191,16 @@ namespace xt
         template <typename std::decay_t<CT>::size_type I, class... Args>
         std::enable_if_t<lesser_condition<I>::value, size_type> index(Args... args) const;
 
-        template <typename std::decay_t<CT>::size_type I, class... Args >
+        template <typename std::decay_t<CT>::size_type I, class... Args>
         std::enable_if_t<!lesser_condition<I>::value, size_type> index(Args... args) const;
 
-        template<typename std::decay_t<CT>::size_type, class T>
+        template <typename std::decay_t<CT>::size_type, class T>
         size_type sliced_access(const xslice<T>& slice) const;
 
-        template<typename std::decay_t<CT>::size_type I, class T, class Arg, class... Args>
+        template <typename std::decay_t<CT>::size_type I, class T, class Arg, class... Args>
         size_type sliced_access(const xslice<T>& slice, Arg arg, Args... args) const;
 
-        template<typename std::decay_t<CT>::size_type I, class T, class... Args>
+        template <typename std::decay_t<CT>::size_type I, class T, class... Args>
         disable_xslice<T, size_type> sliced_access(const T& squeeze, Args...) const;
 
         using temporary_type = typename xcontainer_inner_types<self_type>::temporary_type;
@@ -274,7 +295,7 @@ namespace xt
                     const xview_stepper<is_const, CT, S...>& rhs);
 
 
-    // meta-function returning the shape type for an xview 
+    // meta-function returning the shape type for an xview
     template <class ST, class... S>
     struct xview_shape_type
     {
@@ -304,9 +325,9 @@ namespace xt
      * @sa view
      */
     template <class CT, class... S>
-    template <class... SL>
-    inline xview<CT, S...>::xview(CT e, SL&&... slices) noexcept
-        : m_e(e), m_slices(std::forward<SL>(slices)...),
+    template <class CTA, class... SL>
+    inline xview<CT, S...>::xview(CTA&& e, SL&&... slices) noexcept
+        : m_e(std::forward<CTA>(e)), m_slices(std::forward<SL>(slices)...),
           m_shape(make_sequence<shape_type>(m_e.dimension() - integral_count<S...>() + newaxis_count<S...>(), 0))
     {
         auto func = [](const auto& s) noexcept { return get_size(s); };
@@ -330,9 +351,9 @@ namespace xt
     template <class E>
     inline auto xview<CT, S...>::operator=(const xexpression<E>& e) -> self_type&
     {
-        bool cond = (e.derived_cast().shape().size() == dimension())
-                    && std::equal(shape().begin(), shape().end(), e.derived_cast().shape().begin());
-        if(!cond)
+        bool cond = (e.derived_cast().shape().size() == dimension()) &&
+                    std::equal(shape().begin(), shape().end(), e.derived_cast().shape().begin());
+        if (!cond)
         {
             semantic_base::operator=(broadcast(e.derived_cast(), shape()));
         }
@@ -391,6 +412,78 @@ namespace xt
     {
         return m_slices;
     }
+
+    /**
+     * Returns the data holder of the underlying container (only if the view is on a realized
+     * container). ``xt::eval`` will make sure that the underlying xexpression is 
+     * on a realized container.
+     */
+    template <class E, class... S>
+    template <class T>
+    inline auto xview<E, S...>::data() const ->
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::container_type&>
+    {
+        return m_e.data();
+    }
+
+    /**
+     * Return the strides for the underlying container of the view.
+     */
+    template <class E, class... S>
+    template <class T>
+    inline auto xview<E, S...>::strides() const ->
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::strides_type>
+    {
+        using strides_type = typename T::strides_type;
+        strides_type temp = m_e.strides();
+        strides_type strides = make_sequence<strides_type>(sizeof...(S) - integral_count<S...>(), 0);
+
+        auto func = [](const auto& s) { return xt::step_size(s); };
+
+        for (size_type i = 0; i < strides.size(); ++i) {
+            auto idx = integral_skip<S...>(i);
+            strides[i] = m_e.strides()[idx] * apply<size_type>(idx, func, m_slices);
+        }
+        return strides;
+    }
+
+    /**
+     * Return the pointer to the underlying buffer.
+     */
+    template <class E, class... S>
+    template <class T>
+    inline auto xview<E, S...>::raw_data() const ->
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const value_type*>
+    {
+        return m_e.raw_data();
+    }
+
+    template <class E, class... S>
+    template <class T>
+    inline auto xview<E, S...>::raw_data() ->
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, value_type*>
+    {
+        return m_e.raw_data();
+    }
+
+    /**
+     * Return the offset to the first element of the view in the underlying container.
+     */
+    template <class E, class... S>
+    template <class T>
+    inline auto xview<E, S...>::raw_data_offset() const ->
+        std::enable_if_t<std::is_base_of<xcontainer<std::remove_const_t<T>>, T>::value, const typename T::size_type>
+    {
+        auto func = [](const auto& s) { return xt::value(s, 0); };
+        typename T::size_type offset = 0;
+
+        for (size_type i = 0; i < sizeof...(S); ++i)
+        {
+            size_type s = apply<size_type>(i, func, m_slices) * m_e.strides()[i];
+            offset += s;
+        }
+        return offset;
+    }
     //@}
 
     /**
@@ -529,21 +622,21 @@ namespace xt
     }
 
     template <class CT, class... S>
-    template<typename std::decay_t<CT>::size_type I, class T>
+    template <typename std::decay_t<CT>::size_type I, class T>
     inline auto xview<CT, S...>::sliced_access(const xslice<T>& slice) const -> size_type
     {
         return slice.derived_cast()(0);
     }
 
     template <class CT, class... S>
-    template<typename std::decay_t<CT>::size_type I, class T, class Arg, class... Args>
+    template <typename std::decay_t<CT>::size_type I, class T, class Arg, class... Args>
     inline auto xview<CT, S...>::sliced_access(const xslice<T>& slice, Arg arg, Args... args) const -> size_type
     {
         return slice.derived_cast()(argument<I>(arg, args...));
     }
 
     template <class CT, class... S>
-    template<typename std::decay_t<CT>::size_type I, class T, class... Args>
+    template <typename std::decay_t<CT>::size_type I, class T, class... Args>
     inline auto xview<CT, S...>::sliced_access(const T& squeeze, Args...) const -> disable_xslice<T, size_type>
     {
         return squeeze;
@@ -662,13 +755,13 @@ namespace xt
 
     template <bool is_const, class CT, class... S>
     inline xview_stepper<is_const, CT, S...>::xview_stepper(view_type* view, substepper_type it,
-                                                           size_type offset, bool end)
+                                                            size_type offset, bool end)
         : p_view(view), m_it(it), m_offset(offset)
     {
-        if(!end)
+        if (!end)
         {
             auto func = [](const auto& s) { return xt::value(s, 0); };
-            for(size_type i = 0; i < sizeof...(S); ++i)
+            for (size_type i = 0; i < sizeof...(S); ++i)
             {
                 if (!is_newaxis_slice(i))
                 {
@@ -703,18 +796,19 @@ namespace xt
     template <bool is_const, class CT, class... S>
     inline void xview_stepper<is_const, CT, S...>::reset(size_type dim)
     {
-        if(dim >= m_offset)
+        if (dim >= m_offset)
         {
             auto size_func = [](const auto& s) noexcept { return get_size(s); };
             auto step_func = [](const auto& s) noexcept { return step_size(s); };
             size_type index = integral_skip<S...>(dim);
             if (!is_newaxis_slice(index))
             {
-                size_type size = index < sizeof...(S) ?
-                    apply<size_type>(index, size_func, p_view->slices()) : p_view->shape()[dim];
-                if (size != 0) size = size - 1;
-                size_type step_size = index < sizeof...(S) ?
-                    apply<size_type>(index, step_func, p_view->slices()) : 1;
+                size_type size = index < sizeof...(S) ? apply<size_type>(index, size_func, p_view->slices()) : p_view->shape()[dim];
+                if (size != 0)
+                {
+                    size = size - 1;
+                }
+                size_type step_size = index < sizeof...(S) ? apply<size_type>(index, step_func, p_view->slices()) : 1;
                 index -= newaxis_count_before<S...>(index);
                 m_it.step_back(index, step_size * size);
             }
